Enum OutputEncoding
pub enum OutputEncoding {
UnsignedLittleEndian,
UnsignedBigEndian,
}Expand description
The output encoding of an expression.
Variants
UnsignedLittleEndian
Value with the least-significant byte first. If the output is an integer value, the bytes in the integer are reversed.
UnsignedBigEndian
Value with the most-significant byte first. If the output is an integer value, the bytes in the integer are not reversed.